import{P as r}from"./Passwordless.c72ce9bc.js";import{d as a,ex as i,b as d,c,e as s,eq as _,t as m}from"./registerWidgets.6f5be576.js";import{M as p}from"./member.dec8c29e.js";import{W as f}from"./WidgetsFrame.cc779991.js";import"./CircularLoading.63d0a6e6.js";import"./lottie.df73e4a1.js";import"./icons.b2622455.js";import"./passwordlessManager.1e2193ad.js";import"./pubsub.1dc45978.js";import"./storage.d8b26e7f.js";import"./gateway.1c0effff.js";import"./activeRecord.eb203c6f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="67b0d59b-b034-478f-b15a-5c5c81d69707",e._sentryDebugIdIdentifier="sentry-dbid-67b0d59b-b034-478f-b15a-5c5c81d69707")}catch{}})();const l={class:"login"},u=a({__name:"Login",setup(e){const o=i();async function t(n){await p.login(),o.push({name:"home"})}return(n,b)=>(d(),c("div",l,[s(f,{theme:"white","main-color":"#d14056","font-family":"sans-serif",runtime:"dash"},{default:_(()=>[s(r,{class:"passwordless",onDone:t})]),_:1})]))}});const C=m(u,[["__scopeId","data-v-0e3dc783"]]);export{C as default};
//# sourceMappingURL=Login.93705fcd.js.map
