import{d as i,r,o as c,eM as l,b as f,c as u,eA as b,eS as p}from"./registerWidgets.6f5be576.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="bfd329bb-4bdc-49ec-88c2-187267a65e2e",e._sentryDebugIdIdentifier="sentry-dbid-bfd329bb-4bdc-49ec-88c2-187267a65e2e")}catch{}})();const m=i({__name:"ActionButton",props:{action:{},displayName:{}},emits:["click"],setup(e,{emit:n}){const o=e,s=r(null);return c(()=>{s.value&&o.action.setElement(s.value),l.addAction(o.action)}),(a,t)=>(f(),u("button",{ref_key:"element",ref:s,class:"next-button",onClick:t[0]||(t[0]=d=>n("click")),onKeydown:t[1]||(t[1]=p(d=>n("click"),["enter"]))},b(a.displayName),545))}});export{m as _};
//# sourceMappingURL=ActionButton.vue_vue_type_script_setup_true_lang.86f32ac5.js.map
