import{S as c}from"./Sidebar.a73242b9.js";import{N as m}from"./Navbar.a70a3503.js";import{C as d,D as p,E as l}from"./icons.b2622455.js";import{d as u,ey as b,F as _,a as f,b as g,c as v,e as t,er as y,bw as z,t as w}from"./registerWidgets.6f5be576.js";import{a as h}from"./asyncComputed.ea0bb8a8.js";import"./gateway.1c0effff.js";import{O as I}from"./organization.4d16496d.js";import"./index.1c2771c5.js";import"./Tooltip.48415745.js";import"./logo.084e5d7c.js";import"./passwordlessManager.1e2193ad.js";import"./pubsub.1dc45978.js";import"./storage.d8b26e7f.js";import"./activeRecord.eb203c6f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="91f96e1c-cdf5-47fc-b6dc-ae6ee69cab9e",e._sentryDebugIdIdentifier="sentry-dbid-91f96e1c-cdf5-47fc-b6dc-ae6ee69cab9e")}catch{}})();const O={class:"organization"},D=u({__name:"Organization",setup(e){const n=b().params.organizationId,{result:o}=h(()=>I.get(n)),r=_(()=>o.value?[{label:"My organizations",path:"/organizations"},{label:o.value.name,path:`/organizations/${o.value.id}`}]:void 0),i=[{name:"Organization",items:[{name:"Projects",icon:d,path:"projects"},{name:"Members",icon:p,path:"members"},{name:"Billing",icon:l,path:"billing",unavailable:!0}]}];return(k,x)=>{const s=f("router-view");return g(),v(z,null,[t(m,{breadcrumb:r.value},null,8,["breadcrumb"]),y("div",O,[t(c,{class:"sidebar",sections:i}),t(s)])],64)}}});const G=w(D,[["__scopeId","data-v-51ce7239"]]);export{G as default};
//# sourceMappingURL=Organization.0c4dbd07.js.map
