import{D as c,F as t}from"./registerWidgets.6f5be576.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[e]="c6b7552b-8447-42b6-b8b2-045cd811df2e",r._sentryDebugIdIdentifier="sentry-dbid-c6b7552b-8447-42b6-b8b2-045cd811df2e")}catch{}})();const f=r=>{const e=c({loading:!0,result:null,error:null}),n=l=>(e.value={loading:!1,result:l,error:null},l),s=l=>{e.value={loading:!1,result:null,error:l}},o=()=>{e.value={loading:!0,result:null,error:null},r().then(n).catch(s)};o();const u=t(()=>e.value.loading),a=t(()=>e.value.result),d=t(()=>e.value.error);return{loading:u,result:a,error:d,refetch:o}};export{f as a};
//# sourceMappingURL=asyncComputed.ea0bb8a8.js.map
