import{d as u,ey as b,F as f,b as y,u as g,bu as _}from"./registerWidgets.6f5be576.js";import{a as w}from"./asyncComputed.ea0bb8a8.js";import"./gateway.1c0effff.js";import{M as s}from"./member.dec8c29e.js";import"./index.1c2771c5.js";import{C as I}from"./CrudView.81000b9b.js";import"./passwordlessManager.1e2193ad.js";import"./pubsub.1dc45978.js";import"./storage.d8b26e7f.js";import"./activeRecord.eb203c6f.js";import"./DropdownMenu.ecdd2e52.js";import"./Modal.dd94f88f.js";import"./LoadingIndicator.2446cb23.js";import"./lottie.df73e4a1.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="3ccb3638-f4b4-433c-a10b-291a62a76eea",e._sentryDebugIdIdentifier="sentry-dbid-3ccb3638-f4b4-433c-a10b-291a62a76eea")}catch{}})();const N=u({__name:"Members",setup(e){const o=b().params.organizationId,i=[{key:"email",label:"Email"}],m=async t=>{await s.create(o,t.email),d()},{loading:l,result:c,refetch:d}=w(()=>s.list(o)),p=f(()=>{var t,r;return{columns:[{name:"Email"},{name:"Role"}],rows:(r=(t=c.value)==null?void 0:t.map(n=>({key:n.email,cells:[{text:n.email,classes:["title","centered"]},{text:n.role,classes:["centered"]}]})))!=null?r:[]}});return(t,r)=>(y(),g(I,{"entity-name":"members",loading:_(l),title:"Organization members",description:"List all organization members.","empty-title":"No members yet",table:p.value,"create-button-text":"Add members",fields:i,onCreate:m},null,8,["loading","table"]))}});export{N as default};
//# sourceMappingURL=Members.ece60f42.js.map
