import{M as r}from"./Modal.dd94f88f.js";import{d as a,E as d,r as c,a as _,b as l,c as i,e as n,eq as f,bw as m,er as u,t as p}from"./registerWidgets.6f5be576.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="4359b8c4-d9ae-463d-ac60-99331653b16d",e._sentryDebugIdIdentifier="sentry-dbid-4359b8c4-d9ae-463d-ac60-99331653b16d")}catch{}})();const b=["src"],y=a({__name:"Home",setup(e){const o=d({onboardingForm:""}),t=c(null);return(g,w)=>{const s=_("router-view");return l(),i(m,null,[n(s,{class:"router"}),n(r,{ref_key:"modal",ref:t},{content:f(()=>[u("iframe",{class:"form",src:o.onboardingForm},null,8,b)]),_:1},512)],64)}}});const x=p(y,[["__scopeId","data-v-7e290e34"]]);export{x as default};
//# sourceMappingURL=Home.980146d7.js.map
