.preview[data-v-bf45a749]{box-sizing:border-box;overflow:hidden;min-width:fit-content;padding:2rem}.buttons[data-v-bf45a749]{display:flex;flex-direction:row;gap:1rem;justify-content:flex-end;align-items:center;width:100%}.disable-events[data-v-bf45a749]{pointer-events:none}
