import{d as k,ex as y,F as b,b as h,u as g,bu as _}from"./registerWidgets.6f5be576.js";import{e as H,f as w,g as C}from"./icons.b2622455.js";import{a as x}from"./asyncComputed.ea0bb8a8.js";import{H as d}from"./hooks.c59c1b57.js";import{R as I}from"./RuntimeList.b1e20eb7.js";import"./activeRecord.eb203c6f.js";import"./pubsub.1dc45978.js";import"./DropdownMenu.ecdd2e52.js";import"./CircularLoading.63d0a6e6.js";import"./lottie.df73e4a1.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[n]="6496836b-7076-4b5c-8d08-24de41ed5e77",a._sentryDebugIdIdentifier="sentry-dbid-6496836b-7076-4b5c-8d08-24de41ed5e77")}catch{}})();const $=k({__name:"Hooks",setup(a){const n=y(),{loading:r,result:s,refetch:c}=x(()=>d.list()),l=({key:e})=>n.push({path:`/_editor/hook/${encodeURIComponent(e)}`}),u=async({key:e})=>{var o,t;await((t=(o=s.value)==null?void 0:o.find(i=>i.path===e))==null?void 0:t.duplicate()),c()},p=async()=>{const e=await d.create();l({key:e.path})},m=async({key:e})=>{var o,t;confirm("Are you sure you want to delete this hook?")&&(await((t=(o=s.value)==null?void 0:o.find(i=>i.path===e))==null?void 0:t.delete()),c())},f=b(()=>{var e,o;return{columns:[{name:"Hook Name"},{name:"Path"},{name:"Hook Actions"}],rows:(o=(e=s.value)==null?void 0:e.map(t=>({key:t.path,cells:[{text:t.title,classes:["title","centered"],link:`/_editor/hook/${encodeURIComponent(t.path)}`},{text:t.path},{text:"",classes:["centered"],actions:[{icon:H,label:"Delete",onClick:m,dangerous:!0},{icon:w,label:"Edit Hook",onClick:l},{icon:C,label:"Duplicate",onClick:u}]}]})))!=null?o:[]}});return(e,o)=>(h(),g(I,{loading:_(r),title:"Python Hooks",description:"Trigger your Python scripts with a request.","create-button-text":"Create Hook","empty-title":"No hooks here yet",table:f.value,onCreate:p},null,8,["loading","table"]))}});export{$ as default};
//# sourceMappingURL=Hooks.a1d98e65.js.map
