import{t,b as s,c as a}from"./registerWidgets.6f5be576.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="73541710-d4ae-427d-8dca-0044feabe41e",e._sentryDebugIdIdentifier="sentry-dbid-73541710-d4ae-427d-8dca-0044feabe41e")}catch{}})();const d={},o={class:"organization-settings"};function r(e,n){return s(),a("div",o,"Organization settings")}const f=t(d,[["render",r]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.66e32097.js.map
