import{d as p,ey as u,F as m,b as f,u as _,eq as b,bu as y,eB as g,eC as w,er as i,bh as n,t as h}from"./registerWidgets.6f5be576.js";import{a as I}from"./asyncComputed.ea0bb8a8.js";import"./gateway.1c0effff.js";import{B as x}from"./build.0e7d68c8.js";import"./index.1c2771c5.js";import{C as v}from"./CrudView.81000b9b.js";import{K as B,M as C}from"./icons.b2622455.js";import{r as D}from"./console.8865fb4d.js";import{f as k}from"./index.b048d0fb.js";import"./passwordlessManager.1e2193ad.js";import"./pubsub.1dc45978.js";import"./storage.d8b26e7f.js";import"./activeRecord.eb203c6f.js";import"./DropdownMenu.ecdd2e52.js";import"./Modal.dd94f88f.js";import"./LoadingIndicator.2446cb23.js";import"./lottie.df73e4a1.js";import"./index.2b5138c8.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="e97bbdf4-c6d2-4c80-8572-95f22c0ee456",e._sentryDebugIdIdentifier="sentry-dbid-e97bbdf4-c6d2-4c80-8572-95f22c0ee456")}catch{}})();const S=e=>(g("data-v-e61ab2b9"),e=e(),w(),e),V=S(()=>i("div",{class:"instructions"},[n(" Get started with the local editor in seconds: "),i("pre",null,`    $ pip install abstra --upgrade
    $ abstra serve ./your-project-directory
    `),n(" And you're done! Explore the local editor and start building apps. ")],-1)),j=p({__name:"Builds",setup(e){const s=u().params.projectId,{loading:d,result:c}=I(()=>x.list(s)),l=m(()=>{var a,r;return{columns:[{name:"Id"},{name:"Date"},{name:"Status"},{name:"Actions"}],rows:(r=(a=c.value)==null?void 0:a.map(t=>({key:t.id,cells:[{text:t.id.slice(0,8),classes:["centered"]},{text:k(t.createdAt,Date.now(),{addSuffix:!0}),classes:[]},{text:t.status+(t.log?": "+t.log:""),classes:[]},{text:"",classes:["centered"],actions:[{icon:B,label:"View logs",onClick:()=>D.push({name:"logs",params:{projectId:s},query:{buildId:t.id}})},{icon:C,label:"Download files",onClick:()=>t.download()}]}]})))!=null?r:[]}});return(a,r)=>(f(),_(v,{"entity-name":"build",loading:y(d),title:"Builds",description:"Each build is a version of your app. You can create a new build by deploying your app from the local editor.","empty-title":"No builds here yet",table:l.value},{"empty-description":b(()=>[V]),_:1},8,["loading","table"]))}});const Q=h(j,[["__scopeId","data-v-e61ab2b9"]]);export{Q as default};
//# sourceMappingURL=Builds.58640d9d.js.map
