import{L as o}from"./lottie.df73e4a1.js";import{d as t,r as d,o as r,b as s,c as i,er as c,c2 as _,t as l}from"./registerWidgets.6f5be576.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[e]="dd0a06e2-4290-4f95-8a0e-adc6f46e54a1",n._sentryDebugIdIdentifier="sentry-dbid-dd0a06e2-4290-4f95-8a0e-adc6f46e54a1")}catch{}})();const u={class:"container"},f=t({__name:"LoadingIndicator",setup(n){const e=d(null);return r(()=>{!e.value||o.loadAnimation({container:e.value,renderer:"svg",loop:!0,autoplay:!0,path:"/circularLoading.json"})}),(a,p)=>(s(),i("div",u,[c("div",{ref_key:"animation",ref:e,class:"animation"},null,512),_(a.$slots,"default",{},void 0,!0)]))}});const m=l(f,[["__scopeId","data-v-c30401d8"]]);export{m as L};
//# sourceMappingURL=LoadingIndicator.2446cb23.js.map
