import{t as r,a,b as i,u as c,f as p,g as d,_,h as u,k as l,T as h,P as f,C as g,M as y,s as m,i as b,j as s,l as v,m as w,n as k}from"./registerWidgets.6f5be576.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="5879c009-e3ac-40fc-a711-5758d140c48e",e._sentryDebugIdIdentifier="sentry-dbid-5879c009-e3ac-40fc-a711-5758d140c48e")}catch{}})();const I={};function A(e,t){const n=a("router-view");return i(),c(n,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const x=r(I,[["render",A]]),o=p({history:d("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>_(()=>import("./Player.ab187a36.js"),["assets/Player.ab187a36.js","assets/index.2b5138c8.js","assets/registerWidgets.6f5be576.js","assets/registerWidgets.74435dfa.css","assets/uuid.3957c4d6.js","assets/broker.a6c4370f.js","assets/passwordlessManager.1e2193ad.js","assets/pubsub.1dc45978.js","assets/storage.d8b26e7f.js","assets/Passwordless.c72ce9bc.js","assets/CircularLoading.63d0a6e6.js","assets/lottie.df73e4a1.js","assets/CircularLoading.f81b57b4.css","assets/icons.b2622455.js","assets/Passwordless.86ac0c56.css","assets/executeJs.abe9c76a.js","assets/PlayerNavbar.9ab27066.js","assets/PlayerNavbar.76a7eb2f.css","assets/Steps.413031ec.js","assets/Steps.998aa76d.css","assets/Modal.dd94f88f.js","assets/Modal.5aaf8eba.css","assets/executeJs.887e9a58.css","assets/WidgetsFrame.cc779991.js","assets/WidgetsFrame.0816a5f5.css","assets/ActionButton.vue_vue_type_script_setup_true_lang.86f32ac5.js","assets/broker.54a676ec.css","assets/DashPlayer.74952694.js","assets/DashPlayer.4868beea.css","assets/asyncComputed.ea0bb8a8.js","assets/Player.77337a17.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}});class D{static init(){setInterval(()=>fetch("/_healthcheck"),20*1e3)}}const W=()=>{const e=u({render:()=>l(x)});h.init(),D.init(),e.use(o),e.use(f),e.mount("#app"),e.component("VSelect",g),e.component("Markdown",y),e.component("Message",m),b(e,o),s(e,v),s(e,w),s(e,k)};W();
//# sourceMappingURL=player.cb902430.js.map
